NUR 255 FINAL UPDATED ACTUAL QUESTIONS AND
CORRECT ANSWERS
Question:
Acute renal failure
Answer:
-AKI -Onset: sudden -Common cause: acute tubular necrosis -Dx criteria: Acute
reduction in urine output and or elevation in serum creatinine -Reversibility:
potentially -Primary cause of death: infection -Most commonly, AKI follows severe,
prolonged hypertension, hypovolemia, or exposure to a nephrotoxic agent. -There are
increases in BUN, Creatinine and urine output can be less than 40cc/hr but can be
normal.
Question:
3 causes of AKI
Answer:
Causes: 3 Types. Pre-renal, Intra-renal Post-renal
Question:
Phases of Acute renal failure
Answer:
1. The initiation period: initial when oliguria develops, less than 400ml a day.
2. The oliguria period is an in ability to excrete fluids, regulate fluids, and excrete
metabolic wastes thus they increase.
3. Diuretic phase is when there is large amount of fluids and electrolytes are lost.
4. The last phase is recovery and this can last up to 12 months and most pts. are left with
some renal dysfunction. Lab values are normal for pt.
Question:
Manifestations of ARF
Answer:
-appears very ill and weak -dehydration -headache -oliguria -drowsiness -tachycardia
-crackles -irritability -drowsiness -dry skin -n/v
Question:
Dx of ARF
Answer:
*Labs -UA: proteinuria, RBC's due to glomerular dysfunction, WBC's (inflammation).
-Serum creatinine and BUN increase rapidly and GFR declines -Potassium increases
-anemia (reduced RBC's from decreased erythropoietin secretion) -Metabolic acidosis
occurs. *Cat or MRI, ultrasound, biopsy may be used as well.
,Question:
Treatment of ARF
Answer:
-Focus: Restore and maintain renal function. -Medications, IV fluids, and blood volume
expanders are used to restore perfusion to the kidneys. -Proteins are limited in the diet
with increased carbohydrates to minimize azotemia. -Some cases, may need dialysis.
Question:
Meds for ARF
Answer:
-Dopamine- increase perfusion to the kidneys and increased cardiac output, and dilates
blood vessels of the kidneys. -Furosemide and Mannitol: excrete toxins and help
increase output. -Antihypertensives: control b/p.
Question:
Nursing care for ARF
Answer:
-Good intake and output, daily weights -VS -Semi-Fowlers to help promote respiratory
and cardiac function. -Monitor electrolytes (esp. K as it is increased and Na as it may be
decreased to due fluid retention) and increased Phosphate. -Fluid restriction.
-Administer medications with meals to decrease fluid intake -good skin care. -Good
infection control as infection is the leading cause of death in AKI.
Question:
Elderly and AKI
Answer:
-More susceptible then than younger adults due to dehydration and polypharmacy as
well as impaired function of CV, and diabetes can increase risk as well. -Aging kidney is
less able to compensate for changes in fluid volume and cardiac output. -Patients older
than 65 are less likely to recover from AKI.
Question:
Chronic Renal Failure
Answer:
-CKD -Onset: Gradual, often over many years -Common Cause: diabetic nephropathy
-Dx criteria: GFR <60 mL/min/1.73 m^2 for >30 months and/or Kidney damage >30
months -Progressive and Irriversible -Primary cause of death: CV disease -The presence
of kidney damage for 3 or more months with progressive kidney dysfunction. -Usually
see proteinuria 2 or 3 times in a 3 month period. -Renal mass decreases, loss of
nephrons, deterioration of glomerular filtration and kidney function.
Question:
Stage 1 CKD
Answer:
Stage 1:
-Kidney Damage with normal or increased GFR -GFR >/= 90 -Clinical actions: Dx and tx,
CVD risk reduction, slow prognosis
, Question:
Stage 2 CKD
Answer:
Stage 2:
-Kidney Damage with mild decrease in GFR -GFR 60-89 -Clinical Action Plan: estimation
of progression
Question:
Stage 3 CKD
Answer:
Stage 3:
-Moderate decrease in GFR -GFR 45-59 -Clinical Action: Evaluation and treatments of
complications
Question:
Stage 4 CKD
Answer:
Stage 4:
-Severe decrease in GFR -15-29 -Clinical Action: preparation for renal replacement
therapy (dialysis, kidney transplant)
Question:
Stage 5 CKD
Answer:
Stage 5:
-Kidney Failure -GFR <15 (or dialysis) -Clinical Action: Renal replacement therapy (if
uremia present and patient desires treatment)
Question:
End stage renal disease:
Answer:
-Kidneys unable to excrete metabolic wastes and regulate fluid and electrolytes.
-Glomerulosclerosis and interstitial inflammation with fibrosis lead to declining kidney
function. -Causes: Diabetes, HTN, Glomerulonephritis, cystic kidney disease.
Question:
Most common cause of death in CDK patients
Answer:
-Cardiovascular disease. -MI's -heart disease -peripheral artery disease -heart failure,
cardiomyopathy -stroke etc.
Question:
Risk factors / causes of CKD
Answer:
-Risk Factors: hypertension, increased lipids, diabetes for cardiovascular and CKD.
-Causes: Diabetes, HTN, Glomerulonephritis, cystic kidney disease.
CORRECT ANSWERS
Question:
Acute renal failure
Answer:
-AKI -Onset: sudden -Common cause: acute tubular necrosis -Dx criteria: Acute
reduction in urine output and or elevation in serum creatinine -Reversibility:
potentially -Primary cause of death: infection -Most commonly, AKI follows severe,
prolonged hypertension, hypovolemia, or exposure to a nephrotoxic agent. -There are
increases in BUN, Creatinine and urine output can be less than 40cc/hr but can be
normal.
Question:
3 causes of AKI
Answer:
Causes: 3 Types. Pre-renal, Intra-renal Post-renal
Question:
Phases of Acute renal failure
Answer:
1. The initiation period: initial when oliguria develops, less than 400ml a day.
2. The oliguria period is an in ability to excrete fluids, regulate fluids, and excrete
metabolic wastes thus they increase.
3. Diuretic phase is when there is large amount of fluids and electrolytes are lost.
4. The last phase is recovery and this can last up to 12 months and most pts. are left with
some renal dysfunction. Lab values are normal for pt.
Question:
Manifestations of ARF
Answer:
-appears very ill and weak -dehydration -headache -oliguria -drowsiness -tachycardia
-crackles -irritability -drowsiness -dry skin -n/v
Question:
Dx of ARF
Answer:
*Labs -UA: proteinuria, RBC's due to glomerular dysfunction, WBC's (inflammation).
-Serum creatinine and BUN increase rapidly and GFR declines -Potassium increases
-anemia (reduced RBC's from decreased erythropoietin secretion) -Metabolic acidosis
occurs. *Cat or MRI, ultrasound, biopsy may be used as well.
,Question:
Treatment of ARF
Answer:
-Focus: Restore and maintain renal function. -Medications, IV fluids, and blood volume
expanders are used to restore perfusion to the kidneys. -Proteins are limited in the diet
with increased carbohydrates to minimize azotemia. -Some cases, may need dialysis.
Question:
Meds for ARF
Answer:
-Dopamine- increase perfusion to the kidneys and increased cardiac output, and dilates
blood vessels of the kidneys. -Furosemide and Mannitol: excrete toxins and help
increase output. -Antihypertensives: control b/p.
Question:
Nursing care for ARF
Answer:
-Good intake and output, daily weights -VS -Semi-Fowlers to help promote respiratory
and cardiac function. -Monitor electrolytes (esp. K as it is increased and Na as it may be
decreased to due fluid retention) and increased Phosphate. -Fluid restriction.
-Administer medications with meals to decrease fluid intake -good skin care. -Good
infection control as infection is the leading cause of death in AKI.
Question:
Elderly and AKI
Answer:
-More susceptible then than younger adults due to dehydration and polypharmacy as
well as impaired function of CV, and diabetes can increase risk as well. -Aging kidney is
less able to compensate for changes in fluid volume and cardiac output. -Patients older
than 65 are less likely to recover from AKI.
Question:
Chronic Renal Failure
Answer:
-CKD -Onset: Gradual, often over many years -Common Cause: diabetic nephropathy
-Dx criteria: GFR <60 mL/min/1.73 m^2 for >30 months and/or Kidney damage >30
months -Progressive and Irriversible -Primary cause of death: CV disease -The presence
of kidney damage for 3 or more months with progressive kidney dysfunction. -Usually
see proteinuria 2 or 3 times in a 3 month period. -Renal mass decreases, loss of
nephrons, deterioration of glomerular filtration and kidney function.
Question:
Stage 1 CKD
Answer:
Stage 1:
-Kidney Damage with normal or increased GFR -GFR >/= 90 -Clinical actions: Dx and tx,
CVD risk reduction, slow prognosis
, Question:
Stage 2 CKD
Answer:
Stage 2:
-Kidney Damage with mild decrease in GFR -GFR 60-89 -Clinical Action Plan: estimation
of progression
Question:
Stage 3 CKD
Answer:
Stage 3:
-Moderate decrease in GFR -GFR 45-59 -Clinical Action: Evaluation and treatments of
complications
Question:
Stage 4 CKD
Answer:
Stage 4:
-Severe decrease in GFR -15-29 -Clinical Action: preparation for renal replacement
therapy (dialysis, kidney transplant)
Question:
Stage 5 CKD
Answer:
Stage 5:
-Kidney Failure -GFR <15 (or dialysis) -Clinical Action: Renal replacement therapy (if
uremia present and patient desires treatment)
Question:
End stage renal disease:
Answer:
-Kidneys unable to excrete metabolic wastes and regulate fluid and electrolytes.
-Glomerulosclerosis and interstitial inflammation with fibrosis lead to declining kidney
function. -Causes: Diabetes, HTN, Glomerulonephritis, cystic kidney disease.
Question:
Most common cause of death in CDK patients
Answer:
-Cardiovascular disease. -MI's -heart disease -peripheral artery disease -heart failure,
cardiomyopathy -stroke etc.
Question:
Risk factors / causes of CKD
Answer:
-Risk Factors: hypertension, increased lipids, diabetes for cardiovascular and CKD.
-Causes: Diabetes, HTN, Glomerulonephritis, cystic kidney disease.